pub struct ReflectEvent(/* private fields */);Expand description
A struct used to operate on reflected Event trait of a type.
A ReflectEvent for type T can be obtained via
bevy_reflect::TypeRegistration::data.
Implementations
Sourceimpl ReflectEvent
impl ReflectEvent
Sourcepub fn trigger(
&self,
world: &mut World,
event: &(dyn PartialReflect + 'static),
registry: &TypeRegistry,
)
pub fn trigger( &self, world: &mut World, event: &(dyn PartialReflect + 'static), registry: &TypeRegistry, )
Sourcepub fn new(fns: ReflectEventFns) -> ReflectEvent
pub fn new(fns: ReflectEventFns) -> ReflectEvent
Create a custom implementation of ReflectEvent.
This is an advanced feature, useful for scripting implementations, that should not be used by most users unless you know what you are doing.
Usually you should derive Reflect and add the #[reflect(Event)]
attribute to generate a ReflectEvent implementation automatically.
See ReflectEventFns for more information.
Sourcepub fn fn_pointers(&self) -> &ReflectEventFns
pub fn fn_pointers(&self) -> &ReflectEventFns
The underlying function pointers implementing methods on ReflectEvent.
This is useful when you want to keep track locally of an individual function pointer.
Calling TypeRegistry::get followed by
TypeRegistration::data::<ReflectEvent> can be costly if done several
times per frame. Consider cloning ReflectEvent and keeping it
between frames, cloning a ReflectEvent is very cheap.
If you only need a subset of the methods on ReflectEvent,
use fn_pointers to get the underlying ReflectEventFns
and copy the subset of function pointers you care about.