pub struct ReflectMulAssign {
pub mul_assign: fn(&mut (dyn Reflect + 'static), Box<dyn PartialReflect>) -> Result<(), Option<Box<dyn PartialReflect>>>,
}Expand description
A struct used to perform multiplication assignment on reflected values.
A ReflectMulAssign for type T can be obtained via FromType::from_type.
Fields
mul_assign: fn(&mut (dyn Reflect + 'static), Box<dyn PartialReflect>) -> Result<(), Option<Box<dyn PartialReflect>>>Function pointer implementing ReflectMulAssign::mul_assign().
Implementations
Sourceimpl ReflectMulAssign
impl ReflectMulAssign
Sourcepub fn mul_assign(
&self,
a: &mut (dyn Reflect + 'static),
b: Box<dyn PartialReflect>,
) -> Result<(), Option<Box<dyn PartialReflect>>>
pub fn mul_assign( &self, a: &mut (dyn Reflect + 'static), b: Box<dyn PartialReflect>, ) -> Result<(), Option<Box<dyn PartialReflect>>>
Multiplies a reflected value by another reflected value in place.
Errors
- Returns
Err(None)if the first argument is of an incompatible type. - Returns
Err(Some(b))if the second argument is of an incompatible type.