pub struct ReflectRemAssign {
pub rem_assign: fn(&mut (dyn Reflect + 'static), Box<dyn PartialReflect>) -> Result<(), Option<Box<dyn PartialReflect>>>,
}Expand description
A struct used to perform remainder assignment on reflected values.
A ReflectRemAssign for type T can be obtained via FromType::from_type.
Fields
rem_assign: fn(&mut (dyn Reflect + 'static), Box<dyn PartialReflect>) -> Result<(), Option<Box<dyn PartialReflect>>>Function pointer implementing ReflectRemAssign::rem_assign().
Implementations
Sourceimpl ReflectRemAssign
impl ReflectRemAssign
Sourcepub fn rem_assign(
&self,
a: &mut (dyn Reflect + 'static),
b: Box<dyn PartialReflect>,
) -> Result<(), Option<Box<dyn PartialReflect>>>
pub fn rem_assign( &self, a: &mut (dyn Reflect + 'static), b: Box<dyn PartialReflect>, ) -> Result<(), Option<Box<dyn PartialReflect>>>
Computes the remainder of a reflected value by another reflected value in place.
Errors
- Returns
Err(None)if the first argument is of an incompatible type. - Returns
Err(Some(b))if the second argument is of an incompatible type.