pub struct ReflectSub {
pub sub: fn(Box<dyn PartialReflect>, Box<dyn PartialReflect>) -> Result<Box<dyn Reflect>, (Box<dyn PartialReflect>, Box<dyn PartialReflect>)>,
}Expand description
A struct used to perform subtraction on reflected values.
A ReflectSub for type T can be obtained via FromType::from_type.
Fields
sub: fn(Box<dyn PartialReflect>, Box<dyn PartialReflect>) -> Result<Box<dyn Reflect>, (Box<dyn PartialReflect>, Box<dyn PartialReflect>)>Function pointer implementing ReflectSub::sub().
Implementations
Sourceimpl ReflectSub
impl ReflectSub
Sourcepub fn sub(
&self,
a: Box<dyn PartialReflect>,
b: Box<dyn PartialReflect>,
) -> Result<Box<dyn Reflect>, (Box<dyn PartialReflect>, Box<dyn PartialReflect>)>
pub fn sub( &self, a: Box<dyn PartialReflect>, b: Box<dyn PartialReflect>, ) -> Result<Box<dyn Reflect>, (Box<dyn PartialReflect>, Box<dyn PartialReflect>)>
Subtracts two reflected values, returning the result as a new reflected value.
Errors
Returns Err((a, b)) if the types are incompatible.