pub struct ReflectSubAssign {
pub sub_assign: fn(&mut (dyn Reflect + 'static), Box<dyn PartialReflect>) -> Result<(), Option<Box<dyn PartialReflect>>>,
}Expand description
A struct used to perform subtraction assignment on reflected values.
A ReflectSubAssign for type T can be obtained via FromType::from_type.
Fields
sub_assign: fn(&mut (dyn Reflect + 'static), Box<dyn PartialReflect>) -> Result<(), Option<Box<dyn PartialReflect>>>Function pointer implementing ReflectSubAssign::sub_assign().
Implementations
Sourceimpl ReflectSubAssign
impl ReflectSubAssign
Sourcepub fn sub_assign(
&self,
a: &mut (dyn Reflect + 'static),
b: Box<dyn PartialReflect>,
) -> Result<(), Option<Box<dyn PartialReflect>>>
pub fn sub_assign( &self, a: &mut (dyn Reflect + 'static), b: Box<dyn PartialReflect>, ) -> Result<(), Option<Box<dyn PartialReflect>>>
Subtracts a reflected value from another reflected value in place.
Errors
- Returns
Err(None)if the first argument is of an incompatible type. - Returns
Err(Some(b))if the second argument is of an incompatible type.